package com.ruoyi.cs.mapper;

import java.util.List;
import com.ruoyi.cs.domain.CsApprovalCarbonCopy;
import org.apache.ibatis.annotations.Param;

/**
 * 审核抄送记录Mapper接口
 * 
 * @author cc
 * @date 2024-04-30
 */
public interface CsApprovalCarbonCopyMapper 
{
    /**
     * 查询审核抄送记录
     * 
     * @param carbonCopyId 审核抄送记录主键
     * @return 审核抄送记录
     */
    public CsApprovalCarbonCopy selectCsApprovalCarbonCopyByCarbonCopyId(String carbonCopyId);

    /**
     * 查询审核抄送记录列表
     * 
     * @param csApprovalCarbonCopy 审核抄送记录
     * @return 审核抄送记录集合
     */
    public List<CsApprovalCarbonCopy> selectCsApprovalCarbonCopyList(CsApprovalCarbonCopy csApprovalCarbonCopy);

    /**
     * 新增审核抄送记录
     * 
     * @param csApprovalCarbonCopy 审核抄送记录
     * @return 结果
     */
    public int insertCsApprovalCarbonCopy(CsApprovalCarbonCopy csApprovalCarbonCopy);

    /**
     * 批量新增
     * @param collect
     * @return
     */
    public int batchInsert(@Param("copyList") List<CsApprovalCarbonCopy> collect);

    /**
     * 修改审核抄送记录
     * 
     * @param csApprovalCarbonCopy 审核抄送记录
     * @return 结果
     */
    public int updateCsApprovalCarbonCopy(CsApprovalCarbonCopy csApprovalCarbonCopy);

    /**
     * 删除审核抄送记录
     * 
     * @param carbonCopyId 审核抄送记录主键
     * @return 结果
     */
    public int deleteCsApprovalCarbonCopyByCarbonCopyId(String carbonCopyId);

    /**
     * 批量删除审核抄送记录
     * 
     * @param carbonCopyIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteCsApprovalCarbonCopyByCarbonCopyIds(String[] carbonCopyIds);

    /**
     * 删除审核抄送记录
     * @param formId
     * @param formType
     * @return
     */
    public int deleteCopys(@Param("formId") String formId, @Param("formType") String formType);

    /**
     * 已读用户全部消息
     * @param uid
     * @return
     */
    public int updateReadByUid(@Param("uid")Long uid);
}
